다양한 모드들
===============
*도구 → 옵션 → 일반* 에서 UI 모드를 세 가지 모드 중 하나로 변경 할 수 있습니다.

일반 모드
------------
기본 모드입니다. 특별한 것은 없습니다.

간단 모드
-----------
이 모드에서는 메뉴들이 숨겨지고, 툴바 버튼에서 설명을 표시하고 변수 보기가 자동으로 열립니다.
일반 모드로 돌아가려면 메인 윈도우 오른쪽 최상단의 작은 링크를 사용하세요.

전문가 모드
-----------
This mode looks almost like regular mode, but has some extra features, which are
useful for teachers.
기본 모드와 유사해 보이지만, 선생님들을 위한 추가적인 기능들이 있습니다.

* 보기 메뉴에는 turcar를 전체 화면으로 전환할 수 있는 * 전체 화면 *이 추가 항목으로 있습니다.
* 편집기 또는 보기 탭을 두 번 클릭하면 최대화됩니다. 최대화를 해제하려면 탭을 다시 두 번 클릭하세요.
* 도구 메뉴의 추가 아이템인 * 재생기 열기 ... *를 이용하면 사용자 작업 로그를 재생할 수 있습니다.

